==> viha-5.15.tar.gz: viha-5.15/paikka0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paikka";
$file = basename(__FILE__);

include "common.php";
include "paikka-ok.php";

echo "
<html>
<head>
 <title>VIHA - Sijaintikoodit (paikat)</title>
</head>
" . body_bgcolor() . "
<h1>Sijaintikoodien ksittely ja siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$paikka = get_txt('paikka');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = paikka_add_ok($herja,$alue_id,$paivystys_id,$paikka);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           paikka = '$paikka',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paikka_save_ok($herja,$id,$alue_id,$paivystys_id,$paikka);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = $alue_id,
           paivystys_id=$paivystys_id,
           paikka='$paikka',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  } 
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = paikka_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $alue_id = 1;
    $paivystys_id = 1;
    $paikka = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = paikka_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $paikka = $a['paikka'];
}		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  select_paivystys($paivystys_id);
}

echo "<tr><td>Sijaintikoodi:";
if ($readonly) {
  echo "<td>$paikka\n";
} else {
  echo "<td><input type=\"text\" name=\"paikka\" size=64 maxlength=64";
  echo " value=\"$paikka\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result =
  my_mysql_query("SELECT $table.id,alue.alue,paivystys.nimi,
                         $table.paikka,$table.ts
                  FROM $table,alue,paivystys
                  WHERE $table.alue_id = alue.id
                        AND $table.paivystys_id = paivystys.id
                  ORDER BY alue,paivystys.nimi,paikka");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Alue<TH>Operaatio<TH>Sijaintikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[alue]",
      "<TD>$a[nimi]",
      "<TD>$a[paikka]";
    if (($id == "0") && ($a['id'] > 3)) {
      echo "<td><a href=\"paikka0.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"paikka0.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei sijaintikoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paikka0.php,v 1.12 2009/06/12 10:11:18 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/paikka0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paikka";
$file = basename(__FILE__);

include "common.php";
include "paikka-ok.php";

echo "
<html>
<head>
 <title>VIHA - Sijaintikoodit (paikat)</title>
</head>
" . body_bgcolor() . "
<h1>Sijaintikoodien ksittely ja siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$paikka = get_txt('paikka');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = paikka_add_ok($herja,$alue_id,$paivystys_id,$paikka);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           paikka = '$paikka',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paikka_save_ok($herja,$id,$alue_id,$paivystys_id,$paikka);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = $alue_id,
           paivystys_id=$paivystys_id,
           paikka='$paikka',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  } 
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = paikka_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $alue_id = 1;
    $paivystys_id = 1;
    $paikka = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = paikka_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $paikka = $a['paikka'];
}		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  select_paivystys($paivystys_id);
}

echo "<tr><td>Sijaintikoodi:";
if ($readonly) {
  echo "<td>$paikka\n";
} else {
  echo "<td><input type=\"text\" name=\"paikka\" size=64 maxlength=64";
  echo " value=\"$paikka\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result =
  my_mysql_query("SELECT $table.id,alue.alue,paivystys.nimi,
                         $table.paikka,$table.ts
                  FROM $table,alue,paivystys
                  WHERE $table.alue_id = alue.id
                        AND $table.paivystys_id = paivystys.id
                  ORDER BY alue,paivystys.nimi,paikka");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Alue<TH>Operaatio<TH>Sijaintikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (permission_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[alue]",
      "<TD>$a[nimi]",
      "<TD>$a[paikka]";
    if (($id == "0") && ($a['id'] > 4)) {
      echo "<td><a href=\"paikka0.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"paikka0.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei sijaintikoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paikka0.php,v 1.16 2009/09/29 16:09:15 riku Exp $ -->
